package com.fs.store.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsStoreProductAttrMapper;
import com.fs.store.domain.FsStoreProductAttr;
import com.fs.store.service.IFsStoreProductAttrService;

/**
 * 商品属性Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsStoreProductAttrServiceImpl implements IFsStoreProductAttrService 
{
    @Autowired
    private FsStoreProductAttrMapper fsStoreProductAttrMapper;

    /**
     * 查询商品属性
     * 
     * @param id 商品属性ID
     * @return 商品属性
     */
    @Override
    public FsStoreProductAttr selectFsStoreProductAttrById(Long id)
    {
        return fsStoreProductAttrMapper.selectFsStoreProductAttrById(id);
    }

    /**
     * 查询商品属性列表
     * 
     * @param fsStoreProductAttr 商品属性
     * @return 商品属性
     */
    @Override
    public List<FsStoreProductAttr> selectFsStoreProductAttrList(FsStoreProductAttr fsStoreProductAttr)
    {
        return fsStoreProductAttrMapper.selectFsStoreProductAttrList(fsStoreProductAttr);
    }

    /**
     * 新增商品属性
     * 
     * @param fsStoreProductAttr 商品属性
     * @return 结果
     */
    @Override
    public int insertFsStoreProductAttr(FsStoreProductAttr fsStoreProductAttr)
    {
        return fsStoreProductAttrMapper.insertFsStoreProductAttr(fsStoreProductAttr);
    }

    /**
     * 修改商品属性
     * 
     * @param fsStoreProductAttr 商品属性
     * @return 结果
     */
    @Override
    public int updateFsStoreProductAttr(FsStoreProductAttr fsStoreProductAttr)
    {
        return fsStoreProductAttrMapper.updateFsStoreProductAttr(fsStoreProductAttr);
    }

    /**
     * 批量删除商品属性
     * 
     * @param ids 需要删除的商品属性ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreProductAttrByIds(Long[] ids)
    {
        return fsStoreProductAttrMapper.deleteFsStoreProductAttrByIds(ids);
    }

    /**
     * 删除商品属性信息
     * 
     * @param id 商品属性ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreProductAttrById(Long id)
    {
        return fsStoreProductAttrMapper.deleteFsStoreProductAttrById(id);
    }

    @Override
    public List<FsStoreProductAttr> selectFsStoreProductAttrByProductId(Long productId) {
        return fsStoreProductAttrMapper.selectFsStoreProductAttrByProductId(productId);
    }
}
