package com.fs.store.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.store.domain.FsStoreProductAttr;
import com.fs.store.service.IFsStoreProductAttrService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 商品属性Controller
 * 
 * @author fs
 * @date 2022-03-15
 */
@RestController
@RequestMapping("/store/storeProductAttr")
public class FsStoreProductAttrController extends BaseController
{
    @Autowired
    private IFsStoreProductAttrService fsStoreProductAttrService;

    /**
     * 查询商品属性列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeProductAttr:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsStoreProductAttr fsStoreProductAttr)
    {
        startPage();
        List<FsStoreProductAttr> list = fsStoreProductAttrService.selectFsStoreProductAttrList(fsStoreProductAttr);
        return getDataTable(list);
    }

    /**
     * 导出商品属性列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeProductAttr:export')")
    @Log(title = "商品属性", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsStoreProductAttr fsStoreProductAttr)
    {
        List<FsStoreProductAttr> list = fsStoreProductAttrService.selectFsStoreProductAttrList(fsStoreProductAttr);
        ExcelUtil<FsStoreProductAttr> util = new ExcelUtil<FsStoreProductAttr>(FsStoreProductAttr.class);
        return util.exportExcel(list, "storeProductAttr");
    }

    /**
     * 获取商品属性详细信息
     */
    @PreAuthorize("@ss.hasPermi('store:storeProductAttr:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(fsStoreProductAttrService.selectFsStoreProductAttrById(id));
    }

    /**
     * 新增商品属性
     */
    @PreAuthorize("@ss.hasPermi('store:storeProductAttr:add')")
    @Log(title = "商品属性", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsStoreProductAttr fsStoreProductAttr)
    {
        return toAjax(fsStoreProductAttrService.insertFsStoreProductAttr(fsStoreProductAttr));
    }

    /**
     * 修改商品属性
     */
    @PreAuthorize("@ss.hasPermi('store:storeProductAttr:edit')")
    @Log(title = "商品属性", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsStoreProductAttr fsStoreProductAttr)
    {
        return toAjax(fsStoreProductAttrService.updateFsStoreProductAttr(fsStoreProductAttr));
    }

    /**
     * 删除商品属性
     */
    @PreAuthorize("@ss.hasPermi('store:storeProductAttr:remove')")
    @Log(title = "商品属性", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fsStoreProductAttrService.deleteFsStoreProductAttrByIds(ids));
    }
}
